<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Kleur %1 kopiëren naar klembord</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="50"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin Kleurkiezer is een hulpmiddel om snel schermkleuren te kiezen. RGB- en HEX-codes kunnen worden verkregen via de gekozen kleur en automatisch worden opgeslagen op het klembord. Je hoeft alleen maar met de muis te klikken.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="72"/>
        <source>Deepin Picker</source>
        <translation>Deepin Kleurkiezer</translation>
    </message>
</context>
</TS>